==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/IdentityProviderCredentialsSigning.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentityProviderCredentialsSigning
 */
@JsonPropertyOrder({ IdentityProviderCredentialsSigning.JSON_PROPERTY_KID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class IdentityProviderCredentialsSigning implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_KID = "kid";
    private String kid;

    public IdentityProviderCredentialsSigning() {
    }

    public IdentityProviderCredentialsSigning kid(String kid) {

        this.kid = kid;
        return this;
    }

    /**
     * Get kid
     *
     * @return kid
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getKid() {
        return kid;
    }

    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKid(String kid) {
        this.kid = kid;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentityProviderCredentialsSigning identityProviderCredentialsSigning = (IdentityProviderCredentialsSigning) o;
        return Objects.equals(this.kid, identityProviderCredentialsSigning.kid);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(kid);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentityProviderCredentialsSigning {\n");
        sb.append("    kid: ").append(toIndentedString(kid)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/IdentityProviderCredentialsSigning.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * IdentityProviderCredentialsSigning
 */
@JsonPropertyOrder({ IdentityProviderCredentialsSigning.JSON_PROPERTY_KID })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class IdentityProviderCredentialsSigning implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_KID = "kid";
    private String kid;

    public IdentityProviderCredentialsSigning() {
    }

    public IdentityProviderCredentialsSigning kid(String kid) {

        this.kid = kid;
        return this;
    }

    /**
     * Get kid
     *
     * @return kid
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getKid() {
        return kid;
    }

    @JsonProperty(JSON_PROPERTY_KID)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setKid(String kid) {
        this.kid = kid;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        IdentityProviderCredentialsSigning identityProviderCredentialsSigning = (IdentityProviderCredentialsSigning) o;
        return Objects.equals(this.kid, identityProviderCredentialsSigning.kid);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(kid);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class IdentityProviderCredentialsSigning {\n");
        sb.append("    kid: ").append(toIndentedString(kid)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
